summaryrefslogtreecommitdiffstats
path: root/buildtools/lib/parsers/autotools
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:00:33 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:00:33 -0600
commit7e66d7c3611d907ea28b140281b472bb1c406be6 (patch)
treed0512bf457c2bfe012f455b42ab78651afb81438 /buildtools/lib/parsers/autotools
parentc3b301575a98e4c3505ad95534d6192b65539dab (diff)
downloadtdevelop-7e66d7c3611d907ea28b140281b472bb1c406be6.tar.gz
tdevelop-7e66d7c3611d907ea28b140281b472bb1c406be6.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'buildtools/lib/parsers/autotools')
-rw-r--r--buildtools/lib/parsers/autotools/autotoolsast.cpp14
-rw-r--r--buildtools/lib/parsers/autotools/autotoolsast.h10
2 files changed, 12 insertions, 12 deletions
diff --git a/buildtools/lib/parsers/autotools/autotoolsast.cpp b/buildtools/lib/parsers/autotools/autotoolsast.cpp
index 659fe47f..0512be78 100644
--- a/buildtools/lib/parsers/autotools/autotoolsast.cpp
+++ b/buildtools/lib/parsers/autotools/autotoolsast.cpp
@@ -28,7 +28,7 @@ namespace AutoTools {
AST::~AST()
{
- for (TQValueList<AST*>::iterator it = m_tqchildren.begin(); it != m_tqchildren.end(); ++it)
+ for (TQValueList<AST*>::iterator it = m_children.begin(); it != m_children.end(); ++it)
{
AST *node = *it;
delete node;
@@ -37,13 +37,13 @@ AST::~AST()
void AST::addChildAST(AST *node)
{
- m_tqchildren.append(node);
+ m_children.append(node);
}
void AST::writeBack(TQString &buffer)
{
- for (TQValueList<AST*>::const_iterator it = m_tqchildren.constBegin();
- it != m_tqchildren.constEnd(); ++it)
+ for (TQValueList<AST*>::const_iterator it = m_children.constBegin();
+ it != m_children.constEnd(); ++it)
{
if (*it)
(*it)->writeBack(buffer);
@@ -60,12 +60,12 @@ TQString AST::indentation()
bool AST::hasChildren() const
{
- return !m_tqchildren.isEmpty();
+ return !m_children.isEmpty();
}
-TQValueList<AST*> AST::tqchildren() const
+TQValueList<AST*> AST::children() const
{
- return m_tqchildren;
+ return m_children;
}
//ProjectAST
diff --git a/buildtools/lib/parsers/autotools/autotoolsast.h b/buildtools/lib/parsers/autotools/autotoolsast.h
index 0f5dcdc9..adefc640 100644
--- a/buildtools/lib/parsers/autotools/autotoolsast.h
+++ b/buildtools/lib/parsers/autotools/autotoolsast.h
@@ -37,7 +37,7 @@ namespace AutoTools
* AST node.
* This is the base class. Objects of this type are not created by the parser.
*
* Each AST node holds the list of its tqchildren which are always deleted in the
* destructor. This way, it's possible call delete for only root AST node and
* others will be deleted automatically.
*
@@ -85,20 +85,20 @@ public:
/** @return The indentation string based on node depth.*/
virtual TQString indentation();
//! \return true if this AST has tqchildren
bool hasChildren() const;
/**
* Get the tqchildren of this ast
* \return the list of this ast's childre
*/
- TQValueList<AST*> tqchildren() const;
+ TQValueList<AST*> children() const;
protected:
NodeType m_nodeType;
- TQValueList<AST*> m_tqchildren;
+ TQValueList<AST*> m_children;
private:
int m_depth;
@@ -37,7 +37,7 @@ namespace AutoTools
* This is the base class. Objects of this type are not created by the parser.
*
- * Each AST node holds the list of its tqchildren which are always deleted in the
+ * Each AST node holds the list of its children which are always deleted in the
* destructor. This way, it's possible call delete for only root AST node and
* others will be deleted automatically.
@@ -85,20 +85,20 @@ public:
/** @return The indentation string based on node depth.*/
virtual TQString indentation();
- //! \return true if this AST has tqchildren
+ //! \return true if this AST has children
bool hasChildren() const;
/**
@@ -85,20 +85,20 @@ public:
bool hasChildren() const;
/**
- * Get the tqchildren of this ast
+ * Get the children of this ast
* \return the list of this ast's childre
*/